@@ -3,11 +3,12 @@ import logging
 import os
 from collections import OrderedDict
 from importlib import import_module
+from time import time
 
 import yaml
 
-from automatix import Automatix
-from command import Command
+from .automatix import Automatix
+from .command import Command
 
 yaml.warnings({'YAMLLoadWarning': False})
 
@@ -44,7 +45,7 @@ if CONFIG.get('logging_lib'):
     log_lib = import_module(CONFIG.get('logging_lib'))
     init_logger = log_lib.init_logger
 else:
-    from logger import init_logger
+    from .logger import init_logger
 
 if CONFIG.get('bundlewrap'):
     from bundlewrap.repo import Repository
@@ -155,6 +156,7 @@ def collect_vars(script: dict) -> dict:
 
 
 def main():
+    starttime = time()
     args = _arguments()
     init_logger(name=CONFIG['logger'], debug=args.debug)
 
@@ -171,7 +173,5 @@ def main():
     )
 
     auto.run(args=args)
-
-
-if __name__ == '__main__':
-    main()
+    if 'AUTOMATIX_TIME' in os.environ:
+        auto.env.LOG.info(f'The Automatix script took {round(time()-starttime)}s!')
